@@ -1,24 +1,17 @@
 package Net::GitHub;
 
-use Any::Moose;
 use Net::GitHub::V3;
 
-our $VERSION = '0.60';
+our $VERSION = '0.62';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 sub new {
     my $class = shift;
-    my $params = $class->BUILDARGS(@_);
-
-    return Net::GitHub::V3->new($params);
-
-    #return $class->meta->new_object( __INSTANCE__ => $obj, @_,);
+    Net::GitHub::V3->new(@_);
 }
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-
 1;
+
 __END__
 
 =head1 NAME
@@ -96,7 +89,7 @@ L<http://github.com/fayland/perl-net-github/>
 
 =head1 SEE ALSO
 
-L<Any::Moose>, L<Pithub>
+L<Pithub>
 
 =head1 AUTHOR
 
