@@ -1,8 +1,8 @@
 package Net::GitHub::V3::PullRequests;
 
-use Any::Moose;
+use Moo;
 
-our $VERSION = '0.40';
+our $VERSION = '0.60';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI::Escape;
@@ -10,13 +10,10 @@ use URI::Escape;
 with 'Net::GitHub::V3::Query';
 
 sub pulls {
-    my $self = @_;
-    
-    if (@_ < 3) {
-        unshift @_, $self->repo;
-        unshift @_, $self->u;
-    }
-    my ($user, $repos, $args) = @_;
+    my ($self, $user, $repos, $args) = @_;
+    $user = $self->u unless defined $user;
+    $repos = $self->repo unless defined $repos;
+    $args = $self unless defined $args;
     
     my @p;
     foreach my $p (qw/state/) {
@@ -50,8 +47,7 @@ my %__methods = (
 );
 __build_methods(__PACKAGE__, %__methods);
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
 
 1;
 __END__
